/* computation of theoretical normal flame speed Un */

#include <stdio.h>
#include <math.h>

const float R0 = 8.3142;  /* universal gas constant, [J/(mole*K)] */

int main( void )
{
float Tn = 300., Tv, Tg, theta, T, dT,
	  p = 100000.,
	  cv = 1000., R = 300., cp,
	  A = 3.e9,
	  Hu = 30.e6,
	  YAn = 0.1, YAg = 0.0, YA, W_A, X_A, X_B,
	  Ea = 168000.,
	  mu0 = 1.72e-5, C = 122., T0 = 273.15, mu_v, Pr = 0.72, lambda_v,
	  rhon, rho, k, q, w, I, un;

unsigned i, N = 100;

   cp = cv + R;

   /* theoretical temperature of adiabatic combustion at p=const */
   Tg = Tn + Hu * ( YAn - YAg ) / cp;

   /* temperature interval of chemical reaction */
   theta = R0 * Tg * Tg / Ea;

   /* temperature of inflammation */
   Tv = Tg - 2. * theta;


   /* viscosity at Tv */
   mu_v = mu0 * pow( Tv/T0, 1.5 ) * ( T0 + C ) / ( Tv + C );

   /* heat conductivity at Tv */
   lambda_v = mu_v * cp / Pr;

   rhon = p / ( R * Tn );

   /* molar weight of fuel */
   W_A = R0 / R;

   /**/
   printf( "i       T      YA      rho      [A]     k     wA\n" );

   /* integration of chemical source term */
   dT = ( Tg - Tv ) / N;
   for( i = 0, T = Tv + dT/2, I = 0.; i < N; i++, T += dT ) {
	  /**/
	  YA = YAn - ( YAn - YAg ) * ( T - Tn ) / ( Tg - Tn );
	  /**/
	  rho = rhon * Tn / T;
	  /**/
	  X_A = rho * YA / W_A;
	  X_B = X_A;
	  /**/
	  k = A * exp( - Ea / ( R0 * T ) );
	  q = k * X_A * X_B;
	  I += ( w = - q );
	  /**/
	  printf( "%d %f %f %f %f %f %f \n", i, T, YA, rho, X_A, k, w );
   }

   /**/
   printf( "I = %f \n", I *= dT );

   /* speed of normal flame - final formula */
   un = ( lambda_v / ( rhon * cp * ( Tv - Tn ) ) )
	  * sqrt( - 2. * Hu * W_A * I / lambda_v );
   printf( "un = %f m/s \n", un );

   return 0;
   
}
 /* end main */

